@@ -16,10 +16,9 @@ Usage::
     session_client: WorkMailMessageFlowClient = session.client("workmailmessageflow")
     ```
 """
-from mypy_boto3_workmailmessageflow.client import (
-    WorkMailMessageFlowClient,
-    WorkMailMessageFlowClient as Client,
-)
+from mypy_boto3_workmailmessageflow.client import WorkMailMessageFlowClient
+
+Client = WorkMailMessageFlowClient
 
 
 __all__ = ("Client", "WorkMailMessageFlowClient")
